Struct EraInfo

pub struct EraInfo<T>(/* private fields */);
Wrapper struct for Era related information. It is not a pure encapsulation as these storage items can be accessed directly but nevertheless, its recommended to use EraInfo where we can and add more functions to it as needed.

Implementations

Source

impl<T: Config> EraInfo<T>

pub fn pending_rewards(era: EraIndex, validator: &T::AccountId) -> bool

Returns true if validator has one or more page of era rewards not claimed yet.

pub fn get_paged_exposure( era: EraIndex, validator: &T::AccountId, page: Page, ) -> Option<PagedExposure<T::AccountId, BalanceOf<T>>>

Get exposure for a validator at a given era and page.

This builds a paged exposure from PagedExposureMetadata and ExposurePage of the validator. For older non-paged exposure, it returns the clipped exposure directly.

pub fn get_full_exposure( era: EraIndex, validator: &T::AccountId, ) -> Exposure<T::AccountId, BalanceOf<T>>

Get full exposure of the validator at a given era.

pub fn set_exposure( era: EraIndex, validator: &T::AccountId, exposure: Exposure<T::AccountId, BalanceOf<T>>, )

Store exposure for elected validators at start of an era.