pub struct StakingLedger<T: Config> {
pub stash: T::AccountId,
pub total: BalanceOf<T>,
pub active: BalanceOf<T>,
pub unlocking: BoundedVec<UnlockChunk<BalanceOf<T>>, T::MaxUnlockingChunks>,
pub legacy_claimed_rewards: BoundedVec<EraIndex, T::HistoryDepth>,
/* private fields */
}Expand description
The ledger of a (bonded) stash.
Note: All the reads and mutations to the Ledger, Bonded and Payee storage items
MUST be performed through the methods exposed by this struct, to ensure the consistency of
ledger’s data and corresponding staking lock
TODO: move struct definition and full implementation into /src/ledger.rs. Currently
leaving here to enforce a clean PR diff, given how critical this logic is. Tracking issue
https://github.com/paritytech/substrate/issues/14749.
Fields
stash: T::AccountIdThe stash account whose balance is actually locked and at stake.
total: BalanceOf<T>The total amount of the stash’s balance that we are currently accounting for.
It’s just active plus all the unlocking balances.
active: BalanceOf<T>The total amount of the stash’s balance that will be at stake in any forthcoming rounds.
unlocking: BoundedVec<UnlockChunk<BalanceOf<T>>, T::MaxUnlockingChunks>Any balance that is becoming free, which may eventually be transferred out of the stash (assuming it doesn’t get slashed first). It is assumed that this will be treated as a first in, first out queue where the new (higher value) eras get pushed on the back.
legacy_claimed_rewards: BoundedVec<EraIndex, T::HistoryDepth>List of eras for which the stakers behind a validator have claimed rewards. Only updated for validators.
This is deprecated as of V14 in favor of T::ClaimedRewards and will be removed in future.
Refer to issue https://github.com/paritytech/polkadot-sdk/issues/433
Implementations
Sourceimpl<T: Config> StakingLedger<T>
impl<T: Config> StakingLedger<T>
Sourcepub fn new(stash: T::AccountId, stake: BalanceOf<T>) -> Self
pub fn new(stash: T::AccountId, stake: BalanceOf<T>) -> Self
Returns a new instance of a staking ledger.
The Ledger storage is not mutated. In order to store, StakingLedger::update must be
called on the returned staking ledger.
Note: as the controller accounts are being deprecated, the stash account is the same as the controller account.
Sourceimpl<T: Config> StakingLedger<T>
impl<T: Config> StakingLedger<T>
Sourcepub fn slash(
&mut self,
slash_amount: BalanceOf<T>,
minimum_balance: BalanceOf<T>,
slash_era: EraIndex,
) -> BalanceOf<T>
pub fn slash( &mut self, slash_amount: BalanceOf<T>, minimum_balance: BalanceOf<T>, slash_era: EraIndex, ) -> BalanceOf<T>
Slash the staker for a given amount of balance.
This implements a proportional slashing system, whereby we set our preference to slash as such:
- If any unlocking chunks exist that are scheduled to be unlocked at
slash_era + bonding_durationand onwards, the slash is divided equally between the active ledger and the unlocking chunks. - If no such chunks exist, then only the active balance is slashed.
Note that the above is only a preference. If for any reason the active ledger, with or without some portion of the unlocking chunks that are more justified to be slashed are not enough, then the slashing will continue and will consume as much of the active and unlocking chunks as needed.
This will never slash more than the given amount. If any of the chunks become dusted, the last chunk is slashed slightly less to compensate. Returns the amount of funds actually slashed.
slash_era is the era in which the slash (which is being enacted now) actually happened.
This calls Config::OnStakingUpdate::on_slash with information as to how the slash was
applied.