Type Alias CanceledSlashPayout

pub type CanceledSlashPayout<T: Config> = StorageValue<_GeneratedPrefixForStorageCanceledSlashPayout<T>, BalanceOf<T>, ValueQuery>;
The amount of currency given to reporters of a slash event which was canceled by extraordinary circumstances (e.g. governance).

Storage type is StorageValue with value type BalanceOf < T >.

Aliased Type

pub struct CanceledSlashPayout<T: Config>(/* private fields */);